%--------------------------------------------------------------------------
% TESTING QUALITY APPROXIMATE FEKETE (LEJA) POINTS FOR INTERPOLATION AND
% CUBATURE.
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%% Copyright (C) 2010
%% Len Bos, Stefano De Marchi, Alvise Sommariva, Marco Vianello.
%%
%% This program is free software; you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation; either version 2 of the License, or
%% (at your option) any later version.
%%
%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%%
%% Author:
%%          Len Bos           <leonardpeter.bos@univr.it>
%%          Stefano De Marchi <demarchi@math.unipd.it>
%%          Alvise Sommariva  <alvise@math.unipd.it>
%%          Marco Vianello    <marcov@math.unipd.it>
%%
%% Date: May 24, 2010.
%--------------------------------------------------------------------------

clear all;

warning off;

degv=1:15;           % deg: WAM DEGREE.


% method_unconstrained=0; % 0: fmincon 1: fminsearch 2: fminunc.
extraction_method=1; % extraction_method: 1: QR 2:LU.

family_type=1; % 1: FEKETE. 2: LEBESGUE.

starting_point=0;

constrained_optimization_vector=[1 2 1 2 1 2 1 2 1 2 1 2 1 2]; % 1: CONSTRAINED, 2: UNCONSTRAINED.
mildness_sequence=[0 0 0 0 0 0 0 0 0 0 0 0 0 0];
verbosity_sequence=[-2 -1 -2 -1 -2 -1 -2 -1 -2 -1 -2 -1 -2 -1]; % -2: CONSTRAINED -1/1: UNCONSTRAINED.

do_plots=0;

%--------------------------------------------------------------------------
%               ...... HERE THE MAIN PROGRAM BEGINS ......
%--------------------------------------------------------------------------

s='set_square_fek'; % PUT THE NAME OF YOUR FUNCTION HERE (WITHOUT .m EXTENSION).
diaryname=cat(2,'diary_',s,'.m');

diary on; diary(diaryname);

fprintf('\n \t ');
uu=cat(2,'function pts=',s,'(deg)');
fprintf(uu);

lebv=[]; detv=[]; condv=[];

fprintf('\n \n \t switch deg \n');

for kk=1:length(degv)

    deg=degv(kk);

    %--------------
    % INITIAL SET.
    %--------------

    switch starting_point
        case 0
            pts_start=set_square_fek(deg);
    end

    %---------------
    % OPTIMIZATION.
    %---------------

    pts_in=pts_start;
    cputiming1=cputime;
    for ii=1:length(mildness_sequence)

        mildness=mildness_sequence(ii);
        constrained_optimization=constrained_optimization_vector(ii);
        verbosity=verbosity_sequence(ii);
        
        if constrained_optimization == 1
            
            %[pts_out,value]=general_constrained_optimization_square(deg,...
            %    pts_in,family_type,mildness,-1);
            [pts_out,value]=general_constrained_optimization_square(deg,...
                pts_in,family_type,mildness,verbosity);
            %[pts_out,value]=general_constrained_optimization_square(deg,...
            %    pts_out,family_type,mildness,-3);
            
        else

            [pts_out,value]=general_unconstrained_optimization_square(deg,...
                pts_in,family_type,mildness,verbosity,1);

            [pts_out,value]=general_unconstrained_optimization_square(deg,...
                pts_in,family_type,mildness,verbosity,2);
            
        end

        pts_in=pts_out;
    end
    cputiming2=cputime;

    %-------
    % STATS.
    %-------
    timing=cputiming2-cputiming1;
    [lebs,dets,conds]=do_stats(deg,pts_out,timing);

    lebv=[lebv lebs]; detv=[detv dets]; condv=[condv conds];

    %-------
    % PLOTS.
    %-------
    if do_plots == 1
        pts_bnd=[-1 -1; 1 -1; 1 1; -1 1; -1 -1];
        plot(pts_bnd(:,1),pts_bnd(:,2),'b-',...
            pts_out(:,1),pts_out(:,2),'r+');
    end

end

fprintf('\n \n \t otherwise');
fprintf('\n \n \t pts=pdpts(deg);');
fprintf('\n \n \t end');

fprintf('\n \t %% STATS');
fprintf('\n \t %% |DEGR|  LEBESGUE   | ABS.DET.VAND.| COND. VAND. |')
fprintf('\n \t stats_matrix=[');
for ii=1:length(degv)
    fprintf('\n \t %2.0f %1.5e %1.5e %1.5e',degv(ii),lebv(ii),...
        abs(detv(ii)),condv(ii));
end
fprintf('\n \t ]; \n');


%-----------------------
% FINAL SUMMARY.
%-----------------------

fprintf('\n \t %% ------------------------------------------------- ');
fprintf('\n \t %% |DEGR|  LEBESGUE   | ABS.DET.VAND.| COND. VAND. |')
fprintf('\n \t %% ------------------------------------------------- ');

for ii=1:length(degv)
    fprintf('\n \t %% | %2.0f | %1.5e | %1.5e | %1.5e |',degv(ii),lebv(ii),...
        abs(detv(ii)),condv(ii));
end
fprintf('\n \t %% ------------------------------------------------- \n \n');
diary off;
