%--------------------------------------------------------------------------
% TESTING QUALITY APPROXIMATE FEKETE (LEJA) POINTS FOR INTERPOLATION AND
% CUBATURE.
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%% Copyright (C) 2010
%% Len Bos, Stefano De Marchi, Alvise Sommariva, Marco Vianello.
%%
%% This program is free software; you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation; either version 2 of the License, or
%% (at your option) any later version.
%%
%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%%
%% Author:
%%          Len Bos           <leonardpeter.bos@univr.it>
%%          Stefano De Marchi <demarchi@math.unipd.it>
%%          Alvise Sommariva  <alvise@math.unipd.it>
%%          Marco Vianello    <marcov@math.unipd.it>
%%
%% Date: May 24, 2010.
%--------------------------------------------------------------------------

clear all;

degv=1:20;           % deg: WAM DEGREE.
extraction_method=1; % extraction_method: 1: QR 2:LU.

family_type=1;
unconstrained_method=1; % 0: fmincon 1: fminsearch 2: fminunc

starting_point=0;

mildness_sequence=[0];
verbosity=4;

do_plots=0;

%--------------------------------------------------------------------------
%               ...... HERE THE MAIN PROGRAM BEGINS ......
%--------------------------------------------------------------------------

s='set_square_fek'; % PUT THE NAME OF YOUR FUNCTION HERE (WITHOUT .m EXTENSION).
diaryname=cat(2,'diary_',s,'.m');

diary on; diary(diaryname);

fprintf('\n \t ');
uu=cat(2,'function pts=',s,'(deg)');
fprintf(uu);

fprintf('\n \t switch deg \n \n');

for kk=1:length(degv)

    deg=degv(kk);

    %--------------
    % INITIAL SET.
    %--------------
    [pts,t_start]=set_optpd_fek(deg);

    % t_start=[0 0];

    %---------------
    % OPTIMIZATION.
    %---------------

    t_in=t_start; 
    cputiming1=cputime;
    for ii=1:length(mildness_sequence)
        
        mildness=mildness_sequence(ii);
        
        [pts_out,t_out,value]=general_parm_optimization(deg,...
            t_in,family_type,mildness,verbosity,unconstrained_method);

        t_in=t_out;

    end
    cputiming2=cputime;

    %-------
    % STATS.
    %-------
    timing=cputiming2-cputiming1;
    [lebs,dets,conds]=do_stats(deg,pts_out,timing,t_out);

    lebv(kk)=lebs; detv(kk)=dets; condv(kk)=conds;

end

fprintf('\n \t end \n \n');

%-----------------------
% MATRIX OF STATISTICS.
%-----------------------

fprintf('\n \t %% STATS');
fprintf('\n \t %% |DEGR|  LEBESGUE   | ABS.DET.VAND.| COND. VAND. |')
fprintf('\n \t stats_matrix=[');


for ii=1:length(degv)
    fprintf('\n \t %2.0f %1.5e',degv(ii),lebv(ii));
    fprintf(' %1.5e %1.5e',abs(detv(ii)),condv(ii));
end
fprintf('\n \t ]; \n');


%-----------------------
% FINAL SUMMARY.
%-----------------------

fprintf('\n \t %% ------------------------------------------------- ');
fprintf('\n \t %% |DEGR|  LEBESGUE   | ABS.DET.VAND.| COND. VAND. |')
fprintf('\n \t %% ------------------------------------------------- ');

for ii=1:length(degv)
    fprintf('\n \t %% | %2.0f | %1.5e | %1.5e | %1.5e |',degv(ii),lebv(ii),...
        abs(detv(ii)),condv(ii));
end
fprintf('\n \t %% ------------------------------------------------- \n \n');
diary off;



%-------
% PLOTS.
%-------
if do_plots == 1
    pts_bnd=[-1 -1; 1 -1; 1 1; -1 1; -1 -1];
    plot(pts_bnd(:,1),pts_bnd(:,2),'b-',...
        pts_out(:,1),pts_out(:,2),'r+');
end