
function [lebs,dets,conds]=do_stats(deg,pts,timing,t,do_prints)

leb_default=500;

if nargin < 3
    timing=0;
end

if nargin < 4
    t=[];
end

if nargin < 5
    do_prints = 1;
end

%-------------------------------------------------
% CHECKING IF THE POINTS ARE IN THE UNIT DISK.
% SOME MINIMAL CORRECTIONS.
%-------------------------------------------------

if do_prints == 1
    fprintf('\n \n \t case %2.0f ',deg);
end

x=pts(:,1); y=pts(:,2);

s =(x < -1) + (x > 1) + (y < -1) + (y > 1);

sum_s=sum(s);

if sum_s == 0

    if do_prints == 1
        fprintf('\n \n \t %% PASSED (I).');
    end

else

    ix_m1=find(x < -1);
    x(ix_m1)=-ones(length(ix_m1),1);

    ix_M1=find(x > 1);
    x(ix_M1)=ones(length(ix_M1),1);

    iy_m1=find(y < -1);
    y(iy_m1)=-ones(length(iy_m1),1);

    iy_M1=find(y > 1);
    y(iy_M1)=ones(length(iy_M1),1);

    s =(x < -1) + (x > 1) + (y < -1) + (y > 1);

    sum_s=sum(s);

    if do_prints == 1
        if sum_s == 0
            fprintf('\n \n \t %% PASSED (II).');
        else
            fprintf('\n \n \t %% NOT PASSED.');
        end
    end

end

pts=[x y];

%---------------------------
% COMPUTING BASIC CONSTANTS.
%---------------------------
V_pts = chebvand2d(deg,pts);
dets=det(V_pts);

[pts_leb,w_sq]=tens_cub_sq(leb_default,0,0,1);
V_leb = chebvand2d(deg,pts_leb);

lebs=norm(V_pts'\V_leb',1);
conds=condest(V_pts);

%-----------------------
% DISPLAYING CONSTANTS.
%-----------------------
if do_prints == 1
    fprintf('\n \n \t %% DEGREE: %3.0f',deg);
    fprintf('\n \t %% POINTS: %6.0f',size(pts,1));
    fprintf('\n \t %% LEBESGUE CONSTANT: %2.5e',lebs);
    fprintf('\n \t %% DETERMINANT: %2.5e',dets);
    fprintf('\n \t %% CONDITIONING: %2.5e',conds);
    fprintf('\n \t %% VANDERMONDE: TENSORIAL CHEBYSHEV.');
    if timing > 0
        minuti=floor(timing/60);
        secondi=floor(timing-minuti*60);
        fprintf('\n \t %% CPUTIME (MINUTES:SECONDS): %4.0f : %2.0f.\n',minuti,...
            secondi);
    else
        fprintf('\n');
    end
end

%-----------------------
% DISPLAYING POINTS.
%-----------------------
if do_prints == 1
    L=length(t);
    if L > 0
        fprintf('\n \t t=[');
        for ii=1:L
            fprintf('\n \t %1.30e',t(ii));
        end
        fprintf('\n \t ]; \n');
    end

    fprintf('\n \t pts=[');
    for kk=1:size(pts,1)
        fprintf('\n \t %1.30e %1.30e',pts(kk,1),pts(kk,2));
    end
    fprintf('\n \t ]; \n ');
end